clixx.exceptions
================

.. currentmodule:: clixx.exceptions

Exceptions
----------

.. autoexception:: DefinitionError
    :members:
    :show-inheritance:

.. autoexception:: ParserContextError
    :members:
    :show-inheritance:

.. autoexception:: TypeConversionError
    :members:
    :show-inheritance:

.. autoexception:: CLIXXException
    :members:
    :show-inheritance:

.. autoexception:: TooFewArguments
    :members:
    :show-inheritance:

.. autoexception:: TooManyArguments
    :members:
    :show-inheritance:

.. autoexception:: MissingOption
    :members:
    :show-inheritance:

.. autoexception:: UnknownOption
    :members:
    :show-inheritance:

.. autoexception:: TooFewOptionValues
    :members:
    :show-inheritance:

.. autoexception:: TooManyOptionValues
    :members:
    :show-inheritance:

.. autoexception:: InvalidArgumentValue
    :members:
    :show-inheritance:

.. autoexception:: InvalidOptionValue
    :members:
    :show-inheritance:

.. autoexception:: CommandError
    :members:
    :show-inheritance:

.. autoexception:: GroupError
    :members:
    :show-inheritance:
